@@ -1,20 +1,15 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Links configuration for MySQL system tables
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Config;
 
+use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
 
-/**
- * Class SpecialSchemaLinks
- * @package PhpMyAdmin\Config
- */
 class SpecialSchemaLinks
 {
     /**
@@ -44,22 +39,34 @@ class SpecialSchemaLinks
      *                     )
      *                 ),
      *                 // Page to link
-     *                 'default_page' => './server_privileges.php'
+     *                 'default_page' => './' . Url::getFromRoute('/server/privileges')
      *             )
      *         )
      *     )
      * );
      *
-     * @return array
+     * @return array<string,array<string,array<string,array<string,array<int,array<string,string>>|string>>>>
+     * @phpstan-return array<
+     *              string, array<
+     *                  string, array<
+     *                      string,
+     *                      array{
+     *                          'link_param': string,
+     *                          'link_dependancy_params'?: array<
+     *                                                      int,
+     *                                                      array{'param_info': string, 'column_name': string}
+     *                                                     >,
+     *                          'default_page': string
+     *                      }>
+     *                  >
+     *             >
+     * }
      */
     public static function get(): array
     {
         global $cfg;
 
-        $defaultPage = './' . Util::getScriptNameForOption(
-            $cfg['DefaultTabTable'],
-            'table'
-        );
+        $defaultPage = './' . Util::getScriptNameForOption($cfg['DefaultTabTable'], 'table');
 
         return [
             'mysql' => [
@@ -72,7 +79,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'host',
                             ],
                         ],
-                        'default_page' => './server_privileges.php',
+                        'default_page' => './' . Url::getFromRoute('/server/privileges'),
                     ],
                     'table_name' => [
                         'link_param' => 'table',
@@ -96,7 +103,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'Table_name',
                             ],
                         ],
-                        'default_page' => './tbl_structure.php?change_column=1',
+                        'default_page' => './' . Url::getFromRoute('/table/structure/change', ['change_column' => 1]),
                     ],
                 ],
                 'db' => [
@@ -108,7 +115,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'host',
                             ],
                         ],
-                        'default_page' => './server_privileges.php',
+                        'default_page' => './' . Url::getFromRoute('/server/privileges'),
                     ],
                 ],
                 'event' => [
@@ -120,7 +127,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'db',
                             ],
                         ],
-                        'default_page' => './db_events.php?edit_item=1',
+                        'default_page' => './' . Url::getFromRoute('/database/events', ['edit_item' => 1]),
                     ],
 
                 ],
@@ -147,7 +154,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'table_name',
                             ],
                         ],
-                        'default_page' => './tbl_structure.php',
+                        'default_page' => './' . Url::getFromRoute('/table/structure'),
                     ],
                 ],
                 'innodb_table_stats' => [
@@ -175,7 +182,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'type',
                             ],
                         ],
-                        'default_page' => './db_routines.php?edit_item=1',
+                        'default_page' => './' . Url::getFromRoute('/database/routines', ['edit_item' => 1]),
                     ],
                     'specific_name' => [
                         'link_param' => 'item_name',
@@ -189,7 +196,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'type',
                             ],
                         ],
-                        'default_page' => './db_routines.php?edit_item=1',
+                        'default_page' => './' . Url::getFromRoute('/database/routines', ['edit_item' => 1]),
                     ],
                 ],
                 'proc_priv' => [
@@ -201,7 +208,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'Host',
                             ],
                         ],
-                        'default_page' => './server_privileges.php',
+                        'default_page' => './' . Url::getFromRoute('/server/privileges'),
                     ],
                     'routine_name' => [
                         'link_param' => 'item_name',
@@ -215,7 +222,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'Routine_type',
                             ],
                         ],
-                        'default_page' => './db_routines.php?edit_item=1',
+                        'default_page' => './' . Url::getFromRoute('/database/routines', ['edit_item' => 1]),
                     ],
                 ],
                 'proxies_priv' => [
@@ -227,7 +234,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'Host',
                             ],
                         ],
-                        'default_page' => './server_privileges.php',
+                        'default_page' => './' . Url::getFromRoute('/server/privileges'),
                     ],
                 ],
                 'tables_priv' => [
@@ -239,7 +246,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'Host',
                             ],
                         ],
-                        'default_page' => './server_privileges.php',
+                        'default_page' => './' . Url::getFromRoute('/server/privileges'),
                     ],
                     'table_name' => [
                         'link_param' => 'table',
@@ -261,7 +268,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'host',
                             ],
                         ],
-                        'default_page' => './server_privileges.php',
+                        'default_page' => './' . Url::getFromRoute('/server/privileges'),
                     ],
                 ],
             ],
@@ -289,7 +296,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'table_name',
                             ],
                         ],
-                        'default_page' => './tbl_structure.php?change_column=1',
+                        'default_page' => './' . Url::getFromRoute('/table/structure/change', ['change_column' => 1]),
                     ],
                 ],
                 'key_column_usage' => [
@@ -315,7 +322,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'table_name',
                             ],
                         ],
-                        'default_page' => './tbl_structure.php?change_column=1',
+                        'default_page' => './' . Url::getFromRoute('/table/structure/change', ['change_column' => 1]),
                     ],
                     'referenced_table_name' => [
                         'link_param' => 'table',
@@ -339,7 +346,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'referenced_table_name',
                             ],
                         ],
-                        'default_page' => './tbl_structure.php?change_column=1',
+                        'default_page' => './' . Url::getFromRoute('/table/structure/change', ['change_column' => 1]),
                     ],
                 ],
                 'partitions' => [
@@ -363,7 +370,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'host',
                             ],
                         ],
-                        'default_page' => './server_privileges.php',
+                        'default_page' => './' . Url::getFromRoute('/server/privileges'),
                     ],
                 ],
                 'referential_constraints' => [
@@ -401,7 +408,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'routine_type',
                             ],
                         ],
-                        'default_page' => './db_routines.php',
+                        'default_page' => './' . Url::getFromRoute('/database/routines'),
                     ],
                 ],
                 'schemata' => [
@@ -433,7 +440,7 @@ class SpecialSchemaLinks
                                 'column_name' => 'table_name',
                             ],
                         ],
-                        'default_page' => './tbl_structure.php?change_column=1',
+                        'default_page' => './' . Url::getFromRoute('/table/structure/change', ['change_column' => 1]),
                     ],
                 ],
                 'tables' => [
