@@ -6,20 +6,23 @@ namespace PhpMyAdmin\Controllers\Table;
 
 use PhpMyAdmin\Charsets;
 use PhpMyAdmin\CheckUserPrivileges;
+use PhpMyAdmin\ConfigStorage\Relation;
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\DbTableExists;
 use PhpMyAdmin\Html\Generator;
 use PhpMyAdmin\Index;
 use PhpMyAdmin\Message;
 use PhpMyAdmin\Operations;
-use PhpMyAdmin\Partition;
+use PhpMyAdmin\Partitioning\Partition;
+use PhpMyAdmin\Query\Generator as QueryGenerator;
 use PhpMyAdmin\Query\Utilities;
-use PhpMyAdmin\Relation;
-use PhpMyAdmin\Response;
+use PhpMyAdmin\ResponseRenderer;
 use PhpMyAdmin\StorageEngine;
 use PhpMyAdmin\Template;
 use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
+
+use function __;
 use function count;
 use function implode;
 use function mb_strstr;
@@ -27,6 +30,7 @@ use function mb_strtolower;
 use function mb_strtoupper;
 use function preg_replace;
 use function strlen;
+use function urldecode;
 
 class OperationsController extends AbstractController
 {
@@ -42,21 +46,15 @@ class OperationsController extends AbstractController
     /** @var DatabaseInterface */
     private $dbi;
 
-    /**
-     * @param Response          $response
-     * @param string            $db       Database name.
-     * @param string            $table    Table name.
-     * @param DatabaseInterface $dbi
-     */
     public function __construct(
-        $response,
+        ResponseRenderer $response,
         Template $template,
-        $db,
-        $table,
+        string $db,
+        string $table,
         Operations $operations,
         CheckUserPrivileges $checkUserPrivileges,
         Relation $relation,
-        $dbi
+        DatabaseInterface $dbi
     ) {
         parent::__construct($response, $template, $db, $table);
         $this->operations = $operations;
@@ -65,13 +63,13 @@ class OperationsController extends AbstractController
         $this->dbi = $dbi;
     }
 
-    public function index(): void
+    public function __invoke(): void
     {
-        global $url_params, $reread_info, $tbl_is_view, $tbl_storage_engine;
+        global $urlParams, $reread_info, $tbl_is_view, $tbl_storage_engine;
         global $show_comment, $tbl_collation, $table_info_num_rows, $row_format, $auto_increment, $create_options;
         global $table_alters, $warning_messages, $lowerCaseNames, $db, $table, $reload, $result;
         global $new_tbl_storage_engine, $sql_query, $message_to_show, $columns, $hideOrderTable, $indexes;
-        global $notNull, $comment, $err_url, $cfg;
+        global $notNull, $comment, $errorUrl, $cfg;
 
         $this->checkUserPrivileges->getPrivileges();
 
@@ -89,21 +87,19 @@ class OperationsController extends AbstractController
         Util::checkParameters(['db', 'table']);
 
         $isSystemSchema = Utilities::isSystemSchema($db);
-        $url_params = ['db' => $db, 'table' => $table];
-        $err_url = Util::getScriptNameForOption($cfg['DefaultTabTable'], 'table');
-        $err_url .= Url::getCommon($url_params, '&');
+        $urlParams = ['db' => $db, 'table' => $table];
+        $errorUrl = Util::getScriptNameForOption($cfg['DefaultTabTable'], 'table');
+        $errorUrl .= Url::getCommon($urlParams, '&');
 
         DbTableExists::check();
 
-        $url_params['goto'] = $url_params['back'] = Url::getFromRoute('/table/operations');
+        $urlParams['goto'] = $urlParams['back'] = Url::getFromRoute('/table/operations');
+
+        $relationParameters = $this->relation->getRelationParameters();
 
         /**
-         * Gets relation settings
+         * Reselect current db (needed in some cases probably due to the calling of {@link Relation})
          */
-        $cfgRelation = $this->relation->getRelationsParam();
-
-        // reselect current db (needed in some cases probably due to
-        // the calling of PhpMyAdmin\Relation)
         $this->dbi->selectDb($db);
 
         $reread_info = $pma_table->getStatusInfo(null, false);
@@ -117,6 +113,7 @@ class OperationsController extends AbstractController
             $tbl_storage_engine = $pma_table->getStorageEngine();
             $show_comment = $pma_table->getComment();
         }
+
         $tbl_collation = $pma_table->getCollation();
         $table_info_num_rows = $pma_table->getNumRows();
         $row_format = $pma_table->getRowFormat();
@@ -136,10 +133,7 @@ class OperationsController extends AbstractController
             $create_options['page_checksum'] = $create_options['page_checksum'] ?? '';
         }
 
-        $pma_table = $this->dbi->getTable(
-            $db,
-            $table
-        );
+        $pma_table = $this->dbi->getTable($db, $table);
         $reread_info = false;
         $table_alters = [];
 
@@ -156,6 +150,10 @@ class OperationsController extends AbstractController
             $this->response->addJSON('message', $message);
 
             if ($message->isSuccess()) {
+                if (isset($_POST['submit_move'], $_POST['target_db'])) {
+                    $db = $_POST['target_db'];// Used in Header::getJsParams()
+                }
+
                 $this->response->addJSON('db', $db);
 
                 return;
@@ -176,18 +174,15 @@ class OperationsController extends AbstractController
             if (isset($_POST['new_name'])) {
                 // lower_case_table_names=1 `DB` becomes `db`
                 if ($lowerCaseNames) {
-                    $_POST['new_name'] = mb_strtolower(
-                        $_POST['new_name']
-                    );
+                    $_POST['new_name'] = mb_strtolower($_POST['new_name']);
                 }
+
                 // Get original names before rename operation
                 $oldTable = $pma_table->getName();
                 $oldDb = $pma_table->getDbName();
 
                 if ($pma_table->rename($_POST['new_name'])) {
-                    if (isset($_POST['adjust_privileges'])
-                        && ! empty($_POST['adjust_privileges'])
-                    ) {
+                    if (isset($_POST['adjust_privileges']) && ! empty($_POST['adjust_privileges'])) {
                         $this->operations->adjustPrivilegesRenameOrMoveTable(
                             $oldDb,
                             $oldTable,
@@ -210,7 +205,8 @@ class OperationsController extends AbstractController
                 }
             }
 
-            if (! empty($_POST['new_tbl_storage_engine'])
+            if (
+                ! empty($_POST['new_tbl_storage_engine'])
                 && mb_strtoupper($_POST['new_tbl_storage_engine']) !== $tbl_storage_engine
             ) {
                 $new_tbl_storage_engine = mb_strtoupper($_POST['new_tbl_storage_engine']);
@@ -240,25 +236,18 @@ class OperationsController extends AbstractController
             );
 
             if (count($table_alters) > 0) {
-                $sql_query      = 'ALTER TABLE '
+                $sql_query = 'ALTER TABLE '
                     . Util::backquote($table);
-                $sql_query     .= "\r\n" . implode("\r\n", $table_alters);
-                $sql_query     .= ';';
-                $result         = (bool) $this->dbi->query($sql_query);
-                $reread_info    = true;
+                $sql_query .= "\r\n" . implode("\r\n", $table_alters);
+                $sql_query .= ';';
+                $result = (bool) $this->dbi->query($sql_query);
+                $reread_info = true;
                 unset($table_alters);
                 $warning_messages = $this->operations->getWarningMessagesArray();
             }
 
-            if (isset($_POST['tbl_collation'], $_POST['change_all_collations'])
-                && ! empty($_POST['tbl_collation'])
-                && ! empty($_POST['change_all_collations'])
-            ) {
-                $this->operations->changeAllColumnsCollation(
-                    $db,
-                    $table,
-                    $_POST['tbl_collation']
-                );
+            if (! empty($_POST['tbl_collation']) && ! empty($_POST['change_all_collations'])) {
+                $this->operations->changeAllColumnsCollation($db, $table, $_POST['tbl_collation']);
             }
 
             if (isset($_POST['tbl_collation']) && empty($_POST['tbl_collation'])) {
@@ -273,20 +262,29 @@ class OperationsController extends AbstractController
                 }
             }
         }
+
         /**
          * Reordering the table has been requested by the user
          */
         if (isset($_POST['submitorderby']) && ! empty($_POST['order_field'])) {
-            [$sql_query, $result] = $this->operations->getQueryAndResultForReorderingTable();
+            $sql_query = QueryGenerator::getQueryForReorderingTable(
+                $table,
+                urldecode($_POST['order_field']),
+                $_POST['order_order'] ?? null
+            );
+            $result = $this->dbi->query($sql_query);
         }
 
         /**
          * A partition operation has been requested by the user
          */
-        if (isset($_POST['submit_partition'])
-            && ! empty($_POST['partition_operation'])
-        ) {
-            [$sql_query, $result] = $this->operations->getQueryAndResultForPartition();
+        if (isset($_POST['submit_partition']) && ! empty($_POST['partition_operation'])) {
+            $sql_query = QueryGenerator::getQueryForPartitioningTable(
+                $table,
+                $_POST['partition_operation'],
+                $_POST['partition_name']
+            );
+            $result = $this->dbi->query($sql_query);
         }
 
         if ($reread_info) {
@@ -304,12 +302,14 @@ class OperationsController extends AbstractController
                 $tbl_storage_engine = $pma_table->getStorageEngine();
                 $show_comment = $pma_table->getComment();
             }
+
             $tbl_collation = $pma_table->getCollation();
             $table_info_num_rows = $pma_table->getNumRows();
             $row_format = $pma_table->getRowFormat();
             $auto_increment = $pma_table->getAutoIncrement();
             $create_options = $pma_table->getCreateOptions();
         }
+
         unset($reread_info);
 
         if (isset($result) && empty($message_to_show)) {
@@ -356,6 +356,7 @@ class OperationsController extends AbstractController
 
                     return;
                 }
+
                 unset($warning_messages);
             }
 
@@ -368,10 +369,11 @@ class OperationsController extends AbstractController
                     Generator::getMessage($_message, $sql_query)
                 );
             }
+
             unset($_message);
         }
 
-        $url_params['goto'] = $url_params['back'] = Url::getFromRoute('/table/operations');
+        $urlParams['goto'] = $urlParams['back'] = Url::getFromRoute('/table/operations');
 
         $columns = $this->dbi->getColumns($db, $table);
 
@@ -398,6 +400,7 @@ class OperationsController extends AbstractController
                         break;
                     }
                 }
+
                 if ($notNull) {
                     $hideOrderTable = true;
                     break;
@@ -454,14 +457,14 @@ class OperationsController extends AbstractController
         }
 
         $foreigners = $this->operations->getForeignersForReferentialIntegrityCheck(
-            $url_params,
-            (bool) $cfgRelation['relwork']
+            $urlParams,
+            $relationParameters->relationFeature !== null
         );
 
         $this->render('table/operations/index', [
             'db' => $db,
             'table' => $table,
-            'url_params' => $url_params,
+            'url_params' => $urlParams,
             'columns' => $columns,
             'hide_order_table' => $hideOrderTable,
             'table_comment' => $comment,
