@@ -7,14 +7,13 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\Gis;
 
+use PhpMyAdmin\Image\ImageWrapper;
 use TCPDF;
+
 use function hexdec;
-use function imagearc;
-use function imagecolorallocate;
-use function imagestring;
 use function json_encode;
-use function mb_strlen;
 use function mb_substr;
+use function round;
 use function trim;
 
 /**
@@ -27,8 +26,6 @@ class GisPoint extends GisGeometry
 
     /**
      * A private constructor; prevents direct creation of object.
-     *
-     * @access private
      */
     private function __construct()
     {
@@ -38,8 +35,6 @@ class GisPoint extends GisGeometry
      * Returns the singleton.
      *
      * @return GisPoint the singleton
-     *
-     * @access public
      */
     public static function singleton()
     {
@@ -56,18 +51,11 @@ class GisPoint extends GisGeometry
      * @param string $spatial spatial data of a row
      *
      * @return array an array containing the min, max values for x and y coordinates
-     *
-     * @access public
      */
     public function scaleRow($spatial)
     {
         // Trim to remove leading 'POINT(' and trailing ')'
-        $point
-            = mb_substr(
-                $spatial,
-                6,
-                mb_strlen($spatial) - 7
-            );
+        $point = mb_substr($spatial, 6, -1);
 
         return $this->setMinMax($point, []);
     }
@@ -79,41 +67,32 @@ class GisPoint extends GisGeometry
      * @param string|null $label       Label for the GIS POLYGON object
      * @param string      $point_color Color for the GIS POLYGON object
      * @param array       $scale_data  Array containing data related to scaling
-     * @param resource    $image       Image object
-     *
-     * @return resource the modified image object
-     *
-     * @access public
      */
     public function prepareRowAsPng(
         $spatial,
         ?string $label,
         $point_color,
         array $scale_data,
-        $image
-    ) {
+        ImageWrapper $image
+    ): ImageWrapper {
         // allocate colors
-        $black = imagecolorallocate($image, 0, 0, 0);
-        $red = hexdec(mb_substr($point_color, 1, 2));
-        $green = hexdec(mb_substr($point_color, 3, 2));
-        $blue = hexdec(mb_substr($point_color, 4, 2));
-        $color = imagecolorallocate($image, $red, $green, $blue);
+        $black = $image->colorAllocate(0, 0, 0);
+        $red = (int) hexdec(mb_substr($point_color, 1, 2));
+        $green = (int) hexdec(mb_substr($point_color, 3, 2));
+        $blue = (int) hexdec(mb_substr($point_color, 4, 2));
+        $color = $image->colorAllocate($red, $green, $blue);
+
+        $label = trim($label ?? '');
 
         // Trim to remove leading 'POINT(' and trailing ')'
-        $point
-            = mb_substr(
-                $spatial,
-                6,
-                mb_strlen($spatial) - 7
-            );
+        $point = mb_substr($spatial, 6, -1);
         $points_arr = $this->extractPoints($point, $scale_data);
 
         // draw a small circle to mark the point
         if ($points_arr[0][0] != '' && $points_arr[0][1] != '') {
-            imagearc(
-                $image,
-                $points_arr[0][0],
-                $points_arr[0][1],
+            $image->arc(
+                (int) round($points_arr[0][0]),
+                (int) round($points_arr[0][1]),
                 7,
                 7,
                 0,
@@ -121,13 +100,12 @@ class GisPoint extends GisGeometry
                 $color
             );
             // print label if applicable
-            if (isset($label) && trim($label) != '') {
-                imagestring(
-                    $image,
+            if ($label !== '') {
+                $image->string(
                     1,
-                    $points_arr[0][0],
-                    $points_arr[0][1],
-                    trim($label),
+                    (int) round($points_arr[0][0]),
+                    (int) round($points_arr[0][1]),
+                    $label,
                     $black
                 );
             }
@@ -146,8 +124,6 @@ class GisPoint extends GisGeometry
      * @param TCPDF       $pdf         TCPDF instance
      *
      * @return TCPDF the modified TCPDF instance
-     *
-     * @access public
      */
     public function prepareRowAsPdf(
         $spatial,
@@ -169,31 +145,20 @@ class GisPoint extends GisGeometry
             ],
         ];
 
+        $label = trim($label ?? '');
+
         // Trim to remove leading 'POINT(' and trailing ')'
-        $point
-            = mb_substr(
-                $spatial,
-                6,
-                mb_strlen($spatial) - 7
-            );
+        $point = mb_substr($spatial, 6, -1);
         $points_arr = $this->extractPoints($point, $scale_data);
 
         // draw a small circle to mark the point
         if ($points_arr[0][0] != '' && $points_arr[0][1] != '') {
-            $pdf->Circle(
-                $points_arr[0][0],
-                $points_arr[0][1],
-                2,
-                0,
-                360,
-                'D',
-                $line
-            );
+            $pdf->Circle($points_arr[0][0], $points_arr[0][1], 2, 0, 360, 'D', $line);
             // print label if applicable
-            if (isset($label) && trim($label) != '') {
+            if ($label !== '') {
                 $pdf->SetXY($points_arr[0][0], $points_arr[0][1]);
                 $pdf->SetFontSize(5);
-                $pdf->Cell(0, 0, trim($label));
+                $pdf->Cell(0, 0, $label);
             }
         }
 
@@ -209,27 +174,20 @@ class GisPoint extends GisGeometry
      * @param array  $scale_data  Array containing data related to scaling
      *
      * @return string the code related to a row in the GIS dataset
-     *
-     * @access public
      */
     public function prepareRowAsSvg($spatial, $label, $point_color, array $scale_data)
     {
         $point_options = [
-            'name'         => $label,
-            'id'           => $label . $this->getRandomId(),
-            'class'        => 'point vector',
-            'fill'         => 'white',
-            'stroke'       => $point_color,
+            'name' => $label,
+            'id' => $label . $this->getRandomId(),
+            'class' => 'point vector',
+            'fill' => 'white',
+            'stroke' => $point_color,
             'stroke-width' => 2,
         ];
 
         // Trim to remove leading 'POINT(' and trailing ')'
-        $point
-            = mb_substr(
-                $spatial,
-                6,
-                mb_strlen($spatial) - 7
-            );
+        $point = mb_substr($spatial, 6, -1);
         $points_arr = $this->extractPoints($point, $scale_data);
 
         $row = '';
@@ -239,6 +197,7 @@ class GisPoint extends GisGeometry
             foreach ($point_options as $option => $val) {
                 $row .= ' ' . $option . '="' . trim((string) $val) . '"';
             }
+
             $row .= '/>';
         }
 
@@ -256,12 +215,10 @@ class GisPoint extends GisGeometry
      * @param array  $scale_data  Array containing data related to scaling
      *
      * @return string JavaScript related to a row in the GIS dataset
-     *
-     * @access public
      */
     public function prepareRowAsOl(
         $spatial,
-        $srid,
+        int $srid,
         $label,
         $point_color,
         array $scale_data
@@ -282,9 +239,9 @@ class GisPoint extends GisGeometry
             . 'fill: fill,'
             . 'stroke: stroke';
 
-        if ($label) {
+        if (trim($label) !== '') {
             $text_style = [
-                'text' => $label,
+                'text' => trim($label),
                 'offsetY' => -9,
             ];
             $result .= ',text: new ol.style.Text(' . json_encode($text_style) . ')';
@@ -292,18 +249,14 @@ class GisPoint extends GisGeometry
 
         $result .= '});';
 
-        if ($srid == 0) {
+        if ($srid === 0) {
             $srid = 4326;
         }
+
         $result .= $this->getBoundsForOl($srid, $scale_data);
 
         // Trim to remove leading 'POINT(' and trailing ')'
-        $point
-            = mb_substr(
-                $spatial,
-                6,
-                mb_strlen($spatial) - 7
-            );
+        $point = mb_substr($spatial, 6, -1);
         $points_arr = $this->extractPoints($point, null);
 
         if ($points_arr[0][0] != '' && $points_arr[0][1] != '') {
@@ -319,13 +272,11 @@ class GisPoint extends GisGeometry
     /**
      * Generate the WKT with the set of parameters passed by the GIS editor.
      *
-     * @param array  $gis_data GIS data
-     * @param int    $index    Index into the parameter object
-     * @param string $empty    Point does not adhere to this parameter
+     * @param array       $gis_data GIS data
+     * @param int         $index    Index into the parameter object
+     * @param string|null $empty    Point does not adhere to this parameter
      *
      * @return string WKT with the set of parameters passed by the GIS editor
-     *
-     * @access public
      */
     public function generateWkt(array $gis_data, $index, $empty = '')
     {
@@ -345,8 +296,6 @@ class GisPoint extends GisGeometry
      * @param array $row_data GIS data
      *
      * @return string the WKT for the data from ESRI shape files
-     *
-     * @access public
      */
     public function getShape(array $row_data)
     {
@@ -361,8 +310,6 @@ class GisPoint extends GisGeometry
      * @param int    $index of the geometry
      *
      * @return array params for the GIS data editor from the value of the GIS column
-     *
-     * @access public
      */
     public function generateParams($value, $index = -1)
     {
@@ -378,12 +325,7 @@ class GisPoint extends GisGeometry
         }
 
         // Trim to remove leading 'POINT(' and trailing ')'
-        $point
-            = mb_substr(
-                $wkt,
-                6,
-                mb_strlen($wkt) - 7
-            );
+        $point = mb_substr($wkt, 6, -1);
         $points_arr = $this->extractPoints($point, null);
 
         $params[$index]['POINT']['x'] = $points_arr[0][0];
