@@ -1,30 +1,39 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Handles actions related to GIS POLYGON objects
- *
- * @package PhpMyAdmin-GIS
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Gis;
 
+use PhpMyAdmin\Image\ImageWrapper;
 use TCPDF;
 
+use function array_merge;
+use function array_slice;
+use function count;
+use function explode;
+use function hexdec;
+use function json_encode;
+use function max;
+use function mb_substr;
+use function min;
+use function round;
+use function sqrt;
+use function str_contains;
+use function trim;
+
 /**
  * Handles actions related to GIS POLYGON objects
- *
- * @package PhpMyAdmin-GIS
  */
 class GisPolygon extends GisGeometry
 {
-    // Hold the singleton instance of the class
-    private static $_instance;
+    /** @var self */
+    private static $instance;
 
     /**
      * A private constructor; prevents direct creation of object.
-     *
-     * @access private
      */
     private function __construct()
     {
@@ -34,15 +43,14 @@ class GisPolygon extends GisGeometry
      * Returns the singleton.
      *
      * @return GisPolygon the singleton
-     * @access public
      */
     public static function singleton()
     {
-        if (! isset(self::$_instance)) {
-            self::$_instance = new GisPolygon();
+        if (! isset(self::$instance)) {
+            self::$instance = new GisPolygon();
         }
 
-        return self::$_instance;
+        return self::$instance;
     }
 
     /**
@@ -51,23 +59,18 @@ class GisPolygon extends GisGeometry
      * @param string $spatial spatial data of a row
      *
      * @return array an array containing the min, max values for x and y coordinates
-     * @access public
      */
     public function scaleRow($spatial)
     {
         // Trim to remove leading 'POLYGON((' and trailing '))'
-        $polygon = mb_substr(
-            $spatial,
-            9,
-            mb_strlen($spatial) - 11
-        );
+        $polygon = mb_substr($spatial, 9, -2);
 
         // If the polygon doesn't have an inner ring, use polygon itself
-        if (mb_strpos($polygon, "),(") === false) {
+        if (! str_contains($polygon, '),(')) {
             $ring = $polygon;
         } else {
             // Separate outer ring and use it to determine min-max
-            $parts = explode("),(", $polygon);
+            $parts = explode('),(', $polygon);
             $ring = $parts[0];
         }
 
@@ -81,38 +84,32 @@ class GisPolygon extends GisGeometry
      * @param string|null $label      Label for the GIS POLYGON object
      * @param string      $fill_color Color for the GIS POLYGON object
      * @param array       $scale_data Array containing data related to scaling
-     * @param resource    $image      Image object
-     *
-     * @return resource the modified image object
-     * @access public
      */
     public function prepareRowAsPng(
         $spatial,
         ?string $label,
         $fill_color,
         array $scale_data,
-        $image
-    ) {
+        ImageWrapper $image
+    ): ImageWrapper {
         // allocate colors
-        $black = imagecolorallocate($image, 0, 0, 0);
-        $red = hexdec(mb_substr($fill_color, 1, 2));
-        $green = hexdec(mb_substr($fill_color, 3, 2));
-        $blue = hexdec(mb_substr($fill_color, 4, 2));
-        $color = imagecolorallocate($image, $red, $green, $blue);
+        $black = $image->colorAllocate(0, 0, 0);
+        $red = (int) hexdec(mb_substr($fill_color, 1, 2));
+        $green = (int) hexdec(mb_substr($fill_color, 3, 2));
+        $blue = (int) hexdec(mb_substr($fill_color, 4, 2));
+        $color = $image->colorAllocate($red, $green, $blue);
+
+        $label = trim($label ?? '');
 
         // Trim to remove leading 'POLYGON((' and trailing '))'
-        $polygon = mb_substr(
-            $spatial,
-            9,
-            mb_strlen($spatial) - 11
-        );
+        $polygon = mb_substr($spatial, 9, -2);
 
         // If the polygon doesn't have an inner polygon
-        if (mb_strpos($polygon, "),(") === false) {
+        if (! str_contains($polygon, '),(')) {
             $points_arr = $this->extractPoints($polygon, $scale_data, true);
         } else {
             // Separate outer and inner polygons
-            $parts = explode("),(", $polygon);
+            $parts = explode('),(', $polygon);
             $outer = $parts[0];
             $inner = array_slice($parts, 1);
 
@@ -127,15 +124,14 @@ class GisPolygon extends GisGeometry
         }
 
         // draw polygon
-        imagefilledpolygon($image, $points_arr, count($points_arr) / 2, $color);
+        $image->filledPolygon($points_arr, $color);
         // print label if applicable
-        if (isset($label) && trim($label) != '') {
-            imagestring(
-                $image,
+        if ($label !== '') {
+            $image->string(
                 1,
-                $points_arr[2],
-                $points_arr[3],
-                trim($label),
+                (int) round($points_arr[2]),
+                (int) round($points_arr[3]),
+                $label,
                 $black
             );
         }
@@ -153,7 +149,6 @@ class GisPolygon extends GisGeometry
      * @param TCPDF       $pdf        TCPDF instance
      *
      * @return TCPDF the modified TCPDF instance
-     * @access public
      */
     public function prepareRowAsPdf($spatial, ?string $label, $fill_color, array $scale_data, $pdf)
     {
@@ -167,19 +162,17 @@ class GisPolygon extends GisGeometry
             $blue,
         ];
 
+        $label = trim($label ?? '');
+
         // Trim to remove leading 'POLYGON((' and trailing '))'
-        $polygon = mb_substr(
-            $spatial,
-            9,
-            mb_strlen($spatial) - 11
-        );
+        $polygon = mb_substr($spatial, 9, -2);
 
         // If the polygon doesn't have an inner polygon
-        if (mb_strpos($polygon, "),(") === false) {
+        if (! str_contains($polygon, '),(')) {
             $points_arr = $this->extractPoints($polygon, $scale_data, true);
         } else {
             // Separate outer and inner polygons
-            $parts = explode("),(", $polygon);
+            $parts = explode('),(', $polygon);
             $outer = $parts[0];
             $inner = array_slice($parts, 1);
 
@@ -196,10 +189,10 @@ class GisPolygon extends GisGeometry
         // draw polygon
         $pdf->Polygon($points_arr, 'F*', [], $color, true);
         // print label if applicable
-        if (isset($label) && trim($label) != '') {
+        if ($label !== '') {
             $pdf->SetXY($points_arr[2], $points_arr[3]);
             $pdf->SetFontSize(5);
-            $pdf->Cell(0, 0, trim($label));
+            $pdf->Cell(0, 0, $label);
         }
 
         return $pdf;
@@ -214,44 +207,38 @@ class GisPolygon extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string the code related to a row in the GIS dataset
-     * @access public
      */
     public function prepareRowAsSvg($spatial, $label, $fill_color, array $scale_data)
     {
         $polygon_options = [
-            'name'         => $label,
-            'id'           => $label . mt_rand(),
-            'class'        => 'polygon vector',
-            'stroke'       => 'black',
+            'name' => $label,
+            'id' => $label . $this->getRandomId(),
+            'class' => 'polygon vector',
+            'stroke' => 'black',
             'stroke-width' => 0.5,
-            'fill'         => $fill_color,
-            'fill-rule'    => 'evenodd',
+            'fill' => $fill_color,
+            'fill-rule' => 'evenodd',
             'fill-opacity' => 0.8,
         ];
 
         // Trim to remove leading 'POLYGON((' and trailing '))'
-        $polygon
-            = mb_substr(
-                $spatial,
-                9,
-                mb_strlen($spatial) - 11
-            );
+        $polygon = mb_substr($spatial, 9, -2);
 
         $row = '<path d="';
 
         // If the polygon doesn't have an inner polygon
-        if (mb_strpos($polygon, "),(") === false) {
-            $row .= $this->_drawPath($polygon, $scale_data);
+        if (! str_contains($polygon, '),(')) {
+            $row .= $this->drawPath($polygon, $scale_data);
         } else {
             // Separate outer and inner polygons
-            $parts = explode("),(", $polygon);
+            $parts = explode('),(', $polygon);
             $outer = $parts[0];
             $inner = array_slice($parts, 1);
 
-            $row .= $this->_drawPath($outer, $scale_data);
+            $row .= $this->drawPath($outer, $scale_data);
 
             foreach ($inner as $inner_poly) {
-                $row .= $this->_drawPath($inner_poly, $scale_data);
+                $row .= $this->drawPath($inner_poly, $scale_data);
             }
         }
 
@@ -259,6 +246,7 @@ class GisPolygon extends GisGeometry
         foreach ($polygon_options as $option => $val) {
             $row .= ' ' . $option . '="' . trim((string) $val) . '"';
         }
+
         $row .= '/>';
 
         return $row;
@@ -271,43 +259,45 @@ class GisPolygon extends GisGeometry
      * @param string $spatial    GIS POLYGON object
      * @param int    $srid       Spatial reference ID
      * @param string $label      Label for the GIS POLYGON object
-     * @param string $fill_color Color for the GIS POLYGON object
+     * @param array  $fill_color Color for the GIS POLYGON object
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string JavaScript related to a row in the GIS dataset
-     * @access public
      */
-    public function prepareRowAsOl($spatial, $srid, $label, $fill_color, array $scale_data)
+    public function prepareRowAsOl($spatial, int $srid, $label, $fill_color, array $scale_data)
     {
-        $style_options = [
-            'strokeColor' => '#000000',
-            'strokeWidth' => 0.5,
-            'fillColor'   => $fill_color,
-            'fillOpacity' => 0.8,
-            'label'       => $label,
-            'fontSize'    => 10,
+        $fill_color[] = 0.8;
+        $fill_style = ['color' => $fill_color];
+        $stroke_style = [
+            'color' => [0,0,0],
+            'width' => 0.5,
         ];
-        if ($srid == 0) {
+        $row = 'var style = new ol.style.Style({'
+            . 'fill: new ol.style.Fill(' . json_encode($fill_style) . '),'
+            . 'stroke: new ol.style.Stroke(' . json_encode($stroke_style) . ')';
+        if (trim($label) !== '') {
+            $text_style = ['text' => trim($label)];
+            $row .= ',text: new ol.style.Text(' . json_encode($text_style) . ')';
+        }
+
+        $row .= '});';
+
+        if ($srid === 0) {
             $srid = 4326;
         }
-        $row = $this->getBoundsForOl($srid, $scale_data);
+
+        $row .= $this->getBoundsForOl($srid, $scale_data);
 
         // Trim to remove leading 'POLYGON((' and trailing '))'
-        $polygon
-            =
-            mb_substr(
-                $spatial,
-                9,
-                mb_strlen($spatial) - 11
-            );
+        $polygon = mb_substr($spatial, 9, -2);
 
         // Separate outer and inner polygons
-        $parts = explode("),(", $polygon);
-        $row .= 'vectorLayer.addFeatures(new OpenLayers.Feature.Vector('
-            . $this->getPolygonForOpenLayers($parts, $srid)
-            . ', null, ' . json_encode($style_options) . '));';
+        $parts = explode('),(', $polygon);
 
-        return $row;
+        return $row . $this->getPolygonForOpenLayers($parts, $srid)
+            . 'var feature = new ol.Feature({geometry: polygon});'
+            . 'feature.setStyle(style);'
+            . 'vectorLayer.addFeature(feature);';
     }
 
     /**
@@ -317,9 +307,8 @@ class GisPolygon extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string the code to draw the ring
-     * @access private
      */
-    private function _drawPath($polygon, array $scale_data)
+    private function drawPath($polygon, array $scale_data)
     {
         $points_arr = $this->extractPoints($polygon, $scale_data);
 
@@ -328,6 +317,7 @@ class GisPolygon extends GisGeometry
         foreach ($other_points as $point) {
             $row .= ' L ' . $point[0] . ', ' . $point[1];
         }
+
         $row .= ' Z ';
 
         return $row;
@@ -336,56 +326,43 @@ class GisPolygon extends GisGeometry
     /**
      * Generate the WKT with the set of parameters passed by the GIS editor.
      *
-     * @param array  $gis_data GIS data
-     * @param int    $index    Index into the parameter object
-     * @param string $empty    Value for empty points
+     * @param array       $gis_data GIS data
+     * @param int         $index    Index into the parameter object
+     * @param string|null $empty    Value for empty points
      *
      * @return string WKT with the set of parameters passed by the GIS editor
-     * @access public
      */
     public function generateWkt(array $gis_data, $index, $empty = '')
     {
-        $no_of_lines = isset($gis_data[$index]['POLYGON']['no_of_lines'])
-            ? $gis_data[$index]['POLYGON']['no_of_lines'] : 1;
+        $no_of_lines = $gis_data[$index]['POLYGON']['no_of_lines'] ?? 1;
         if ($no_of_lines < 1) {
             $no_of_lines = 1;
         }
 
         $wkt = 'POLYGON(';
         for ($i = 0; $i < $no_of_lines; $i++) {
-            $no_of_points = isset($gis_data[$index]['POLYGON'][$i]['no_of_points'])
-                ? $gis_data[$index]['POLYGON'][$i]['no_of_points'] : 4;
+            $no_of_points = $gis_data[$index]['POLYGON'][$i]['no_of_points'] ?? 4;
             if ($no_of_points < 4) {
                 $no_of_points = 4;
             }
+
             $wkt .= '(';
             for ($j = 0; $j < $no_of_points; $j++) {
-                $wkt .= ((isset($gis_data[$index]['POLYGON'][$i][$j]['x'])
-                        && trim((string) $gis_data[$index]['POLYGON'][$i][$j]['x']) != '')
+                $wkt .= (isset($gis_data[$index]['POLYGON'][$i][$j]['x'])
+                        && trim((string) $gis_data[$index]['POLYGON'][$i][$j]['x']) != ''
                         ? $gis_data[$index]['POLYGON'][$i][$j]['x'] : $empty)
-                    . ' ' . ((isset($gis_data[$index]['POLYGON'][$i][$j]['y'])
-                        && trim((string) $gis_data[$index]['POLYGON'][$i][$j]['y']) != '')
+                    . ' ' . (isset($gis_data[$index]['POLYGON'][$i][$j]['y'])
+                        && trim((string) $gis_data[$index]['POLYGON'][$i][$j]['y']) != ''
                         ? $gis_data[$index]['POLYGON'][$i][$j]['y'] : $empty) . ',';
             }
-            $wkt
-                =
-                mb_substr(
-                    $wkt,
-                    0,
-                    mb_strlen($wkt) - 1
-                );
+
+            $wkt = mb_substr($wkt, 0, -1);
             $wkt .= '),';
         }
-        $wkt
-            =
-            mb_substr(
-                $wkt,
-                0,
-                mb_strlen($wkt) - 1
-            );
-        $wkt .= ')';
 
-        return $wkt;
+        $wkt = mb_substr($wkt, 0, -1);
+
+        return $wkt . ')';
     }
 
     /**
@@ -394,19 +371,16 @@ class GisPolygon extends GisGeometry
      * @param array $ring array of points forming the ring
      *
      * @return float the area of a closed simple polygon
-     * @access public
+     *
      * @static
      */
     public static function area(array $ring)
     {
-
         $no_of_points = count($ring);
 
         // If the last point is same as the first point ignore it
         $last = count($ring) - 1;
-        if (($ring[0]['x'] == $ring[$last]['x'])
-            && ($ring[0]['y'] == $ring[$last]['y'])
-        ) {
+        if (($ring[0]['x'] == $ring[$last]['x']) && ($ring[0]['y'] == $ring[$last]['y'])) {
             $no_of_points--;
         }
 
@@ -420,6 +394,7 @@ class GisPolygon extends GisGeometry
             $area += $ring[$i]['x'] * $ring[$j]['y'];
             $area -= $ring[$i]['y'] * $ring[$j]['x'];
         }
+
         $area /= 2.0;
 
         return $area;
@@ -431,15 +406,13 @@ class GisPolygon extends GisGeometry
      *
      * @param array $ring array of points forming the ring
      *
-     * @return bool whether a set of points represents an outer ring
-     * @access public
      * @static
      */
-    public static function isOuterRing(array $ring)
+    public static function isOuterRing(array $ring): bool
     {
         // If area is negative then it's in clockwise orientation,
         // i.e. it's an outer ring
-        return GisPolygon::area($ring) < 0;
+        return self::area($ring) < 0;
     }
 
     /**
@@ -448,17 +421,13 @@ class GisPolygon extends GisGeometry
      * @param array $point   x, y coordinates of the point
      * @param array $polygon array of points forming the ring
      *
-     * @return bool whether a given point is inside a given polygon
-     * @access public
      * @static
      */
-    public static function isPointInsidePolygon(array $point, array $polygon)
+    public static function isPointInsidePolygon(array $point, array $polygon): bool
     {
         // If first point is repeated at the end remove it
         $last = count($polygon) - 1;
-        if (($polygon[0]['x'] == $polygon[$last]['x'])
-            && ($polygon[0]['y'] == $polygon[$last]['y'])
-        ) {
+        if (($polygon[0]['x'] == $polygon[$last]['x']) && ($polygon[0]['y'] == $polygon[$last]['y'])) {
             $polygon = array_slice($polygon, 0, $last);
         }
 
@@ -505,9 +474,7 @@ class GisPolygon extends GisGeometry
      *
      * @param array $ring array of points forming the ring
      *
-     * @return array|bool a point on the surface of the ring
-     * @access public
-     * @static
+     * @return array|false a point on the surface of the ring
      */
     public static function getPointOnSurface(array $ring)
     {
@@ -536,7 +503,7 @@ class GisPolygon extends GisGeometry
 
         // Always keep $epsilon < 1 to go with the reduction logic down here
         $epsilon = 0.1;
-        $denominator = sqrt(pow($y1 - $y0, 2) + pow($x0 - $x1, 2));
+        $denominator = sqrt(($y1 - $y0) ** 2 + ($x0 - $x1) ** 2);
         $pointA = [];
         $pointB = [];
 
@@ -551,30 +518,30 @@ class GisPolygon extends GisGeometry
 
             // One of the points should be inside the polygon,
             // unless epsilon chosen is too large
-            if (GisPolygon::isPointInsidePolygon($pointA, $ring)) {
+            if (self::isPointInsidePolygon($pointA, $ring)) {
                 return $pointA;
             }
 
-            if (GisPolygon::isPointInsidePolygon($pointB, $ring)) {
+            if (self::isPointInsidePolygon($pointB, $ring)) {
                 return $pointB;
             }
 
             //If both are outside the polygon reduce the epsilon and
             //recalculate the points(reduce exponentially for faster convergence)
-            $epsilon = pow($epsilon, 2);
+            $epsilon **= 2;
             if ($epsilon == 0) {
                 return false;
             }
         }
     }
 
-    /** Generate parameters for the GIS data editor from the value of the GIS column.
+    /**
+     * Generate parameters for the GIS data editor from the value of the GIS column.
      *
      * @param string $value Value of the GIS column
      * @param int    $index Index of the geometry
      *
      * @return array params for the GIS data editor from the value of the GIS column
-     * @access public
      */
     public function generateParams($value, $index = -1)
     {
@@ -590,15 +557,9 @@ class GisPolygon extends GisGeometry
         }
 
         // Trim to remove leading 'POLYGON((' and trailing '))'
-        $polygon
-            =
-            mb_substr(
-                $wkt,
-                9,
-                mb_strlen($wkt) - 11
-            );
+        $polygon = mb_substr($wkt, 9, -2);
         // Separate each linestring
-        $linerings = explode("),(", $polygon);
+        $linerings = explode('),(', $polygon);
         $params[$index]['POLYGON']['no_of_lines'] = count($linerings);
 
         $j = 0;
@@ -610,6 +571,7 @@ class GisPolygon extends GisGeometry
                 $params[$index]['POLYGON'][$j][$i]['x'] = $points_arr[$i][0];
                 $params[$index]['POLYGON'][$j][$i]['y'] = $points_arr[$i][1];
             }
+
             $j++;
         }
 
