@@ -1,17 +1,13 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Set of methods used to build dumps of tables as Latex
- *
- * @package    PhpMyAdmin-Export
- * @subpackage Latex
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Plugins\Export;
 
 use PhpMyAdmin\DatabaseInterface;
-use PhpMyAdmin\Export;
 use PhpMyAdmin\Plugins\ExportPlugin;
 use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup;
 use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyRootGroup;
@@ -19,35 +15,36 @@ use PhpMyAdmin\Properties\Options\Items\BoolPropertyItem;
 use PhpMyAdmin\Properties\Options\Items\RadioPropertyItem;
 use PhpMyAdmin\Properties\Options\Items\TextPropertyItem;
 use PhpMyAdmin\Properties\Plugins\ExportPluginProperties;
-use PhpMyAdmin\Relation;
-use PhpMyAdmin\Transformations;
 use PhpMyAdmin\Util;
+use PhpMyAdmin\Version;
+
+use function __;
+use function count;
+use function in_array;
+use function mb_strpos;
+use function mb_substr;
+use function str_replace;
+use function stripslashes;
+
+use const PHP_VERSION;
 
 /**
  * Handles the export for the Latex format
- *
- * @package    PhpMyAdmin-Export
- * @subpackage Latex
  */
 class ExportLatex extends ExportPlugin
 {
     /**
-     * Constructor
+     * @psalm-return non-empty-lowercase-string
      */
-    public function __construct()
+    public function getName(): string
     {
-        parent::__construct();
-        // initialize the specific export sql variables
-        $this->initSpecificVariables();
-        $this->setProperties();
+        return 'latex';
     }
 
     /**
-     * Initialize the local variables that are used for export Latex
-     *
-     * @return void
+     * Initialize the local variables that are used for export Latex.
      */
-    protected function initSpecificVariables()
+    protected function init(): void
     {
         /* Messages used in default captions */
         $GLOBALS['strLatexContent'] = __('Content of table @TABLE@');
@@ -55,18 +52,11 @@ class ExportLatex extends ExportPlugin
         $GLOBALS['strLatexStructure'] = __('Structure of table @TABLE@');
     }
 
-    /**
-     * Sets the export Latex properties
-     *
-     * @return void
-     */
-    protected function setProperties()
+    protected function setProperties(): ExportPluginProperties
     {
         global $plugin_param;
         $hide_structure = false;
-        if ($plugin_param['export_type'] == 'table'
-            && ! $plugin_param['single_table']
-        ) {
+        if ($plugin_param['export_type'] === 'table' && ! $plugin_param['single_table']) {
             $hide_structure = true;
         }
 
@@ -79,15 +69,13 @@ class ExportLatex extends ExportPlugin
         // create the root group that will be the options field for
         // $exportPluginProperties
         // this will be shown as "Format specific options"
-        $exportSpecificOptions = new OptionsPropertyRootGroup(
-            "Format Specific Options"
-        );
+        $exportSpecificOptions = new OptionsPropertyRootGroup('Format Specific Options');
 
         // general options main group
-        $generalOptions = new OptionsPropertyMainGroup("general_opts");
+        $generalOptions = new OptionsPropertyMainGroup('general_opts');
         // create primary items and add them to the group
         $leaf = new BoolPropertyItem(
-            "caption",
+            'caption',
             __('Include table caption')
         );
         $generalOptions->addProperty($leaf);
@@ -96,15 +84,15 @@ class ExportLatex extends ExportPlugin
 
         // what to dump (structure/data/both) main group
         $dumpWhat = new OptionsPropertyMainGroup(
-            "dump_what",
+            'dump_what',
             __('Dump table')
         );
         // create primary items and add them to the group
-        $leaf = new RadioPropertyItem("structure_or_data");
+        $leaf = new RadioPropertyItem('structure_or_data');
         $leaf->setValues(
             [
-                'structure'          => __('structure'),
-                'data'               => __('data'),
+                'structure' => __('structure'),
+                'data' => __('data'),
                 'structure_and_data' => __('structure and data'),
             ]
         );
@@ -115,78 +103,81 @@ class ExportLatex extends ExportPlugin
         // structure options main group
         if (! $hide_structure) {
             $structureOptions = new OptionsPropertyMainGroup(
-                "structure",
+                'structure',
                 __('Object creation options')
             );
             $structureOptions->setForce('data');
             // create primary items and add them to the group
             $leaf = new TextPropertyItem(
-                "structure_caption",
+                'structure_caption',
                 __('Table caption:')
             );
             $leaf->setDoc('faq6-27');
             $structureOptions->addProperty($leaf);
             $leaf = new TextPropertyItem(
-                "structure_continued_caption",
+                'structure_continued_caption',
                 __('Table caption (continued):')
             );
             $leaf->setDoc('faq6-27');
             $structureOptions->addProperty($leaf);
             $leaf = new TextPropertyItem(
-                "structure_label",
+                'structure_label',
                 __('Label key:')
             );
             $leaf->setDoc('faq6-27');
             $structureOptions->addProperty($leaf);
-            if (! empty($GLOBALS['cfgRelation']['relation'])) {
+            $relationParameters = $this->relation->getRelationParameters();
+            if ($relationParameters->relationFeature !== null) {
                 $leaf = new BoolPropertyItem(
-                    "relation",
+                    'relation',
                     __('Display foreign key relationships')
                 );
                 $structureOptions->addProperty($leaf);
             }
+
             $leaf = new BoolPropertyItem(
-                "comments",
+                'comments',
                 __('Display comments')
             );
             $structureOptions->addProperty($leaf);
-            if (! empty($GLOBALS['cfgRelation']['mimework'])) {
+            if ($relationParameters->browserTransformationFeature !== null) {
                 $leaf = new BoolPropertyItem(
-                    "mime",
-                    __('Display media (MIME) types')
+                    'mime',
+                    __('Display media types')
                 );
                 $structureOptions->addProperty($leaf);
             }
+
             // add the main group to the root group
             $exportSpecificOptions->addProperty($structureOptions);
         }
 
         // data options main group
         $dataOptions = new OptionsPropertyMainGroup(
-            "data",
+            'data',
             __('Data dump options')
         );
         $dataOptions->setForce('structure');
         // create primary items and add them to the group
         $leaf = new BoolPropertyItem(
-            "columns",
+            'columns',
             __('Put columns names in the first row:')
         );
         $dataOptions->addProperty($leaf);
         $leaf = new TextPropertyItem(
-            "data_caption",
+            'data_caption',
             __('Table caption:')
         );
         $leaf->setDoc('faq6-27');
         $dataOptions->addProperty($leaf);
         $leaf = new TextPropertyItem(
-            "data_continued_caption",
+            'data_continued_caption',
             __('Table caption (continued):')
         );
         $leaf->setDoc('faq6-27');
         $dataOptions->addProperty($leaf);
         $leaf = new TextPropertyItem(
-            "data_label",
+            'data_label',
             __('Label key:')
         );
         $leaf->setDoc('faq6-27');
@@ -201,31 +192,30 @@ class ExportLatex extends ExportPlugin
 
         // set the options for the export plugin property item
         $exportPluginProperties->setOptions($exportSpecificOptions);
-        $this->properties = $exportPluginProperties;
+
+        return $exportPluginProperties;
     }
 
     /**
      * Outputs export header
-     *
-     * @return bool Whether it succeeded
      */
-    public function exportHeader()
+    public function exportHeader(): bool
     {
-        global $crlf;
-        global $cfg;
+        global $crlf, $cfg, $dbi;
 
         $head = '% phpMyAdmin LaTeX Dump' . $crlf
-            . '% version ' . PMA_VERSION . $crlf
+            . '% version ' . Version::VERSION . $crlf
             . '% https://www.phpmyadmin.net/' . $crlf
             . '%' . $crlf
             . '% ' . __('Host:') . ' ' . $cfg['Server']['host'];
         if (! empty($cfg['Server']['port'])) {
             $head .= ':' . $cfg['Server']['port'];
         }
+
         $head .= $crlf
             . '% ' . __('Generation Time:') . ' '
             . Util::localisedDate() . $crlf
-            . '% ' . __('Server version:') . ' ' . $GLOBALS['dbi']->getVersionString() . $crlf
+            . '% ' . __('Server version:') . ' ' . $dbi->getVersionString() . $crlf
             . '% ' . __('PHP Version:') . ' ' . PHP_VERSION . $crlf;
 
         return $this->export->outputHandler($head);
@@ -233,10 +223,8 @@ class ExportLatex extends ExportPlugin
 
     /**
      * Outputs export footer
-     *
-     * @return bool Whether it succeeded
      */
-    public function exportFooter()
+    public function exportFooter(): bool
     {
         return true;
     }
@@ -244,19 +232,18 @@ class ExportLatex extends ExportPlugin
     /**
      * Outputs database header
      *
-     * @param string $db       Database name
-     * @param string $db_alias Aliases of db
-     *
-     * @return bool Whether it succeeded
+     * @param string $db      Database name
+     * @param string $dbAlias Aliases of db
      */
-    public function exportDBHeader($db, $db_alias = '')
+    public function exportDBHeader($db, $dbAlias = ''): bool
     {
-        if (empty($db_alias)) {
-            $db_alias = $db;
+        if (empty($dbAlias)) {
+            $dbAlias = $db;
         }
+
         global $crlf;
         $head = '% ' . $crlf
-            . '% ' . __('Database:') . ' \'' . $db_alias . '\'' . $crlf
+            . '% ' . __('Database:') . ' \'' . $dbAlias . '\'' . $crlf
             . '% ' . $crlf;
 
         return $this->export->outputHandler($head);
@@ -266,10 +253,8 @@ class ExportLatex extends ExportPlugin
      * Outputs database footer
      *
      * @param string $db Database name
-     *
-     * @return bool Whether it succeeded
      */
-    public function exportDBFooter($db)
+    public function exportDBFooter($db): bool
     {
         return true;
     }
@@ -277,13 +262,11 @@ class ExportLatex extends ExportPlugin
     /**
      * Outputs CREATE DATABASE statement
      *
-     * @param string $db          Database name
-     * @param string $export_type 'server', 'database', 'table'
-     * @param string $db_alias    Aliases of db
-     *
-     * @return bool Whether it succeeded
+     * @param string $db         Database name
+     * @param string $exportType 'server', 'database', 'table'
+     * @param string $dbAlias    Aliases of db
      */
-    public function exportDBCreate($db, $export_type, $db_alias = '')
+    public function exportDBCreate($db, $exportType, $dbAlias = ''): bool
     {
         return true;
     }
@@ -291,41 +274,38 @@ class ExportLatex extends ExportPlugin
     /**
      * Outputs the content of a table in JSON format
      *
-     * @param string $db        database name
-     * @param string $table     table name
-     * @param string $crlf      the end of line sequence
-     * @param string $error_url the url to go back in case of error
-     * @param string $sql_query SQL query for obtaining data
-     * @param array  $aliases   Aliases of db/table/columns
-     *
-     * @return bool Whether it succeeded
+     * @param string $db       database name
+     * @param string $table    table name
+     * @param string $crlf     the end of line sequence
+     * @param string $errorUrl the url to go back in case of error
+     * @param string $sqlQuery SQL query for obtaining data
+     * @param array  $aliases  Aliases of db/table/columns
      */
     public function exportData(
         $db,
         $table,
         $crlf,
-        $error_url,
-        $sql_query,
+        $errorUrl,
+        $sqlQuery,
         array $aliases = []
-    ) {
+    ): bool {
+        global $dbi;
+
         $db_alias = $db;
         $table_alias = $table;
         $this->initAlias($aliases, $db_alias, $table_alias);
 
-        $result = $GLOBALS['dbi']->tryQuery(
-            $sql_query,
-            DatabaseInterface::CONNECT_USER,
-            DatabaseInterface::QUERY_UNBUFFERED
-        );
+        $result = $dbi->tryQuery($sqlQuery, DatabaseInterface::CONNECT_USER, DatabaseInterface::QUERY_UNBUFFERED);
 
-        $columns_cnt = $GLOBALS['dbi']->numFields($result);
+        $columns_cnt = $result->numFields();
         $columns = [];
         $columns_alias = [];
-        for ($i = 0; $i < $columns_cnt; $i++) {
-            $columns[$i] = $col_as = $GLOBALS['dbi']->fieldName($result, $i);
+        foreach ($result->getFieldNames() as $i => $col_as) {
+            $columns[$i] = $col_as;
             if (! empty($aliases[$db]['tables'][$table]['columns'][$col_as])) {
                 $col_as = $aliases[$db]['tables'][$table]['columns'][$col_as];
             }
+
             $columns_alias[$i] = $col_as;
         }
 
@@ -335,6 +315,7 @@ class ExportLatex extends ExportPlugin
         for ($index = 0; $index < $columns_cnt; $index++) {
             $buffer .= 'l|';
         }
+
         $buffer .= '} ' . $crlf;
 
         $buffer .= ' \\hline \\endhead \\hline \\endfoot \\hline ' . $crlf;
@@ -362,6 +343,7 @@ class ExportLatex extends ExportPlugin
                 )
                 . '} \\\\';
         }
+
         if (! $this->export->outputHandler($buffer)) {
             return false;
         }
@@ -378,26 +360,29 @@ class ExportLatex extends ExportPlugin
             if (! $this->export->outputHandler($buffer . ' \\endfirsthead ' . $crlf)) {
                 return false;
             }
+
             if (isset($GLOBALS['latex_caption'])) {
-                if (! $this->export->outputHandler(
-                    '\\caption{'
-                    . Util::expandUserString(
-                        $GLOBALS['latex_data_continued_caption'],
-                        [
-                            'texEscape',
-                            static::class,
-                        ],
-                        [
-                            'table' => $table_alias,
-                            'database' => $db_alias,
-                        ]
+                if (
+                    ! $this->export->outputHandler(
+                        '\\caption{'
+                        . Util::expandUserString(
+                            $GLOBALS['latex_data_continued_caption'],
+                            [
+                                'texEscape',
+                                static::class,
+                            ],
+                            [
+                                'table' => $table_alias,
+                                'database' => $db_alias,
+                            ]
+                        )
+                        . '} \\\\ '
                     )
-                    . '} \\\\ '
-                )
                 ) {
                     return false;
                 }
             }
+
             if (! $this->export->outputHandler($buffer . '\\endhead \\endfoot' . $crlf)) {
                 return false;
             }
@@ -408,13 +393,11 @@ class ExportLatex extends ExportPlugin
         }
 
         // print the whole table
-        while ($record = $GLOBALS['dbi']->fetchAssoc($result)) {
+        while ($record = $result->fetchAssoc()) {
             $buffer = '';
             // print each row
             for ($i = 0; $i < $columns_cnt; $i++) {
-                if ($record[$columns[$i]] !== null
-                    && isset($record[$columns[$i]])
-                ) {
+                if ($record[$columns[$i]] !== null && isset($record[$columns[$i]])) {
                     $column_value = self::texEscape(
                         stripslashes($record[$columns[$i]])
                     );
@@ -423,12 +406,13 @@ class ExportLatex extends ExportPlugin
                 }
 
                 // last column ... no need for & character
-                if ($i == ($columns_cnt - 1)) {
+                if ($i == $columns_cnt - 1) {
                     $buffer .= $column_value;
                 } else {
-                    $buffer .= $column_value . " & ";
+                    $buffer .= $column_value . ' & ';
                 }
             }
+
             $buffer .= ' \\\\ \\hline ' . $crlf;
             if (! $this->export->outputHandler($buffer)) {
                 return false;
@@ -436,14 +420,21 @@ class ExportLatex extends ExportPlugin
         }
 
         $buffer = ' \\end{longtable}' . $crlf;
-        if (! $this->export->outputHandler($buffer)) {
-            return false;
-        }
 
-        $GLOBALS['dbi']->freeResult($result);
+        return $this->export->outputHandler($buffer);
+    }
 
-        return true;
-    } // end getTableLaTeX
+    /**
+     * Outputs result raw query
+     *
+     * @param string $errorUrl the url to go back in case of error
+     * @param string $sqlQuery the rawquery to output
+     * @param string $crlf     the seperator for a file
+     */
+    public function exportRawQuery(string $errorUrl, string $sqlQuery, string $crlf): bool
+    {
+        return $this->exportData('', '', $crlf, $errorUrl, $sqlQuery);
+    }
 
     /**
      * Outputs table's structure
@@ -451,44 +442,44 @@ class ExportLatex extends ExportPlugin
      * @param string $db          database name
      * @param string $table       table name
      * @param string $crlf        the end of line sequence
-     * @param string $error_url   the url to go back in case of error
-     * @param string $export_mode 'create_table', 'triggers', 'create_view',
-     *                            'stand_in'
-     * @param string $export_type 'server', 'database', 'table'
+     * @param string $errorUrl    the url to go back in case of error
+     * @param string $exportMode  'create_table', 'triggers', 'create_view',
+     *                             'stand_in'
+     * @param string $exportType  'server', 'database', 'table'
      * @param bool   $do_relation whether to include relation comments
      * @param bool   $do_comments whether to include the pmadb-style column
      *                            comments as comments in the structure;
      *                            this is deprecated but the parameter is
-     *                            left here because export.php calls
+     *                            left here because /export calls
      *                            exportStructure() also for other
      *                            export types which use this parameter
      * @param bool   $do_mime     whether to include mime comments
      * @param bool   $dates       whether to include creation/update/check dates
      * @param array  $aliases     Aliases of db/table/columns
-     *
-     * @return bool Whether it succeeded
      */
     public function exportStructure(
         $db,
         $table,
         $crlf,
-        $error_url,
-        $export_mode,
-        $export_type,
+        $errorUrl,
+        $exportMode,
+        $exportType,
         $do_relation = false,
         $do_comments = false,
         $do_mime = false,
         $dates = false,
         array $aliases = []
-    ) {
+    ): bool {
+        global $dbi;
+
         $db_alias = $db;
         $table_alias = $table;
         $this->initAlias($aliases, $db_alias, $table_alias);
 
-        global $cfgRelation;
+        $relationParameters = $this->relation->getRelationParameters();
 
         /* We do not export triggers */
-        if ($export_mode == 'triggers') {
+        if ($exportMode === 'triggers') {
             return true;
         }
 
@@ -496,21 +487,23 @@ class ExportLatex extends ExportPlugin
          * Get the unique keys in the table
          */
         $unique_keys = [];
-        $keys = $GLOBALS['dbi']->getTableIndexes($db, $table);
+        $keys = $dbi->getTableIndexes($db, $table);
         foreach ($keys as $key) {
-            if ($key['Non_unique'] == 0) {
-                $unique_keys[] = $key['Column_name'];
+            if ($key['Non_unique'] != 0) {
+                continue;
             }
+
+            $unique_keys[] = $key['Column_name'];
         }
 
         /**
          * Gets fields properties
          */
-        $GLOBALS['dbi']->selectDb($db);
+        $dbi->selectDb($db);
 
         // Check if we can use Relations
-        list($res_rel, $have_rel) = $this->relation->getRelationsAndStatus(
-            $do_relation && ! empty($cfgRelation['relation']),
+        [$res_rel, $have_rel] = $this->relation->getRelationsAndStatus(
+            $do_relation && $relationParameters->relationFeature !== null,
             $db,
             $table
         );
@@ -527,12 +520,15 @@ class ExportLatex extends ExportPlugin
         if ($do_relation && $have_rel) {
             $alignment .= 'l|';
         }
+
         if ($do_comments) {
             $alignment .= 'l|';
         }
-        if ($do_mime && $cfgRelation['mimework']) {
+
+        if ($do_mime && $relationParameters->browserTransformationFeature !== null) {
             $alignment .= 'l|';
         }
+
         $buffer = $alignment . '} ' . $crlf;
 
         $header = ' \\hline ';
@@ -543,11 +539,13 @@ class ExportLatex extends ExportPlugin
         if ($do_relation && $have_rel) {
             $header .= ' & \\multicolumn{1}{|c|}{\\textbf{' . __('Links to') . '}}';
         }
+
         if ($do_comments) {
             $header .= ' & \\multicolumn{1}{|c|}{\\textbf{' . __('Comments') . '}}';
             $comments = $this->relation->getComments($db, $table);
         }
-        if ($do_mime && $cfgRelation['mimework']) {
+
+        if ($do_mime && $relationParameters->browserTransformationFeature !== null) {
             $header .= ' & \\multicolumn{1}{|c|}{\\textbf{MIME}}';
             $mime_map = $this->transformations->getMime($db, $table, true);
         }
@@ -577,6 +575,7 @@ class ExportLatex extends ExportPlugin
                 )
                 . '} \\\\' . $crlf;
         }
+
         $buffer .= $header . ' \\\\ \\hline \\hline' . $crlf
             . '\\endfirsthead' . $crlf;
         // Table caption on next pages
@@ -595,13 +594,14 @@ class ExportLatex extends ExportPlugin
                 )
                 . '} \\\\ ' . $crlf;
         }
+
         $buffer .= $header . ' \\\\ \\hline \\hline \\endhead \\endfoot ' . $crlf;
 
         if (! $this->export->outputHandler($buffer)) {
             return false;
         }
 
-        $fields = $GLOBALS['dbi']->getColumns($db, $table);
+        $fields = $dbi->getColumns($db, $table);
         foreach ($fields as $row) {
             $extracted_columnspec = Util::extractColumnSpec($row['Type']);
             $type = $extracted_columnspec['print_type'];
@@ -610,7 +610,7 @@ class ExportLatex extends ExportPlugin
             }
 
             if (! isset($row['Default'])) {
-                if ($row['Null'] != 'NO') {
+                if ($row['Null'] !== 'NO') {
                     $row['Default'] = 'NULL';
                 }
             }
@@ -621,64 +621,60 @@ class ExportLatex extends ExportPlugin
             }
 
             $local_buffer = $col_as . "\000" . $type . "\000"
-                . (($row['Null'] == '' || $row['Null'] == 'NO')
+                . ($row['Null'] == '' || $row['Null'] === 'NO'
                     ? __('No') : __('Yes'))
-                . "\000" . (isset($row['Default']) ? $row['Default'] : '');
+                . "\000" . ($row['Default'] ?? '');
 
             if ($do_relation && $have_rel) {
                 $local_buffer .= "\000";
-                $local_buffer .= $this->getRelationString(
-                    $res_rel,
-                    $field_name,
-                    $db,
-                    $aliases
-                );
+                $local_buffer .= $this->getRelationString($res_rel, $field_name, $db, $aliases);
             }
-            if ($do_comments && $cfgRelation['commwork']) {
+
+            if ($do_comments && $relationParameters->columnCommentsFeature !== null) {
                 $local_buffer .= "\000";
                 if (isset($comments[$field_name])) {
                     $local_buffer .= $comments[$field_name];
                 }
             }
-            if ($do_mime && $cfgRelation['mimework']) {
+
+            if ($do_mime && $relationParameters->browserTransformationFeature !== null) {
                 $local_buffer .= "\000";
                 if (isset($mime_map[$field_name])) {
-                    $local_buffer .= str_replace(
-                        '_',
-                        '/',
-                        $mime_map[$field_name]['mimetype']
-                    );
+                    $local_buffer .= str_replace('_', '/', $mime_map[$field_name]['mimetype']);
                 }
             }
+
             $local_buffer = self::texEscape($local_buffer);
-            if ($row['Key'] == 'PRI') {
-                $pos = mb_strpos($local_buffer, "\000");
+            if ($row['Key'] === 'PRI') {
+                $pos = (int) mb_strpos($local_buffer, "\000");
                 $local_buffer = '\\textit{'
                     .
                     mb_substr($local_buffer, 0, $pos)
                     . '}' .
                     mb_substr($local_buffer, $pos);
             }
+
             if (in_array($field_name, $unique_keys)) {
-                $pos = mb_strpos($local_buffer, "\000");
+                $pos = (int) mb_strpos($local_buffer, "\000");
                 $local_buffer = '\\textbf{'
                     .
                     mb_substr($local_buffer, 0, $pos)
                     . '}' .
                     mb_substr($local_buffer, $pos);
             }
+
             $buffer = str_replace("\000", ' & ', $local_buffer);
             $buffer .= ' \\\\ \\hline ' . $crlf;
 
             if (! $this->export->outputHandler($buffer)) {
                 return false;
             }
-        } // end while
+        }
 
         $buffer = ' \\end{longtable}' . $crlf;
 
         return $this->export->outputHandler($buffer);
-    } // end of the 'exportStructure' method
+    }
 
     /**
      * Escapes some special characters for use in TeX/LaTeX
